==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/search/functions_a.js <==
var searchData=
[
  ['sdkversion_0',['sdkVersion',['../interface_t_n_k_nav_services.html#abdc1dd2cd0aa9bf243a908a8ad0c5341',1,'TNKNavServices']]],
  ['searchrouteswithrequest_3acompletion_3a_1',['searchRoutesWithRequest:completion:',['../interface_t_n_k_drive_nav_manager.html#ae012ed762cb37f3a8cd31f415dfb2916',1,'TNKDriveNavManager::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_drive_route_plan_service.html#a9406cba0843b5d35c4d6da759116bbcb',1,'TNKDriveRoutePlanService::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_ride_nav_manager.html#a1230430432ef55cfde29b4e65362ac67',1,'TNKRideNavManager::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_walk_nav_manager.html#ab870679b698cf1b30fd1f38859d6941e',1,'TNKWalkNavManager::searchRoutesWithRequest:completion:()']]],
  ['setallcomponentvisibility_3a_2',['setAllComponentVisibility:',['../interface_t_n_k_drive_nav_view.html#a2d3478fcc22632d07261dfb881abf587',1,'TNKDriveNavView::setAllComponentVisibility:()'],['../interface_t_n_k_travel_nav_view.html#a3901489c5d84b7f90c364e889fce0ed9',1,'TNKTravelNavView::setAllComponentVisibility:()']]],
  ['setavoidareas_3a_3',['setAvoidAreas:',['../interface_t_n_k_drive_route_request.html#a1cc109bb2ec38709fdbc6c3dc4b0324e',1,'TNKDriveRouteRequest']]],
  ['setbackuprouteshidden_3abackuprouteids_3a_4',['setBackupRoutesHidden:backupRouteIDs:',['../interface_t_n_k_drive_nav_view.html#aef36f84cd4d60e072880e0c12d9d0479',1,'TNKDriveNavView::setBackupRoutesHidden:backupRouteIDs:()'],['../interface_t_n_k_travel_nav_view.html#afd822589919f5b5a65931299ea7dfad4',1,'TNKTravelNavView::setBackupRoutesHidden:backupRouteIDs:()']]],
  ['setcaricon_3asize_3a_5',['setCarIcon:size:',['../interface_t_n_k_navi_traffic_bar_widget.html#a6ae261ec2f5531a02dc130aa3b25f994',1,'TNKNaviTrafficBarWidget']]],
  ['setcustomareaheight_3a_6',['setCustomAreaHeight:',['../interface_t_n_k_travel_nav_view.html#acaa724d91ba411e2cb8e7a1f728624c5',1,'TNKTravelNavView']]],
  ['setdebuglog_3a_7',['setDebugLog:',['../interface_t_n_k_location_adapter.html#a69704e3eb0ece8a84744b979358e4bcb',1,'TNKLocationAdapter']]],
  ['setdestarriveoffrouteradius_3adestoffrouteradius_3a_8',['setDestArriveOffRouteRadius:destOffRouteRadius:',['../interface_t_n_k_drive_nav_manager.html#a8d49bbc52f699449b7ee78263dabb8ad',1,'TNKDriveNavManager']]],
  ['setheight_3a_9',['setHeight:',['../interface_t_n_k_custom_area_view.html#a4b368007cb0cd16648a7856cee7a8331',1,'TNKCustomAreaView']]],
  ['setlogon_3a_10',['setLogOn:',['../interface_t_n_k_logger.html#a5e167f9ee4688db33861bc2d1e07650d',1,'TNKLogger']]],
  ['setmapstyle_3a_11',['setMapStyle:',['../category_t_n_k_base_nav_view_07_q_map_view_08.html#a1dd5c15f6cf02b8da4a9aee650eb867c',1,'TNKBaseNavView(QMapView)::setMapStyle:()'],['../interface_t_n_k_base_nav_view.html#a1dd5c15f6cf02b8da4a9aee650eb867c',1,'TNKBaseNavView::setMapStyle:()']]],
  ['setnaverouteplancachesize_3a_12',['setNaveRoutePlanCacheSize:',['../interface_t_n_k_base_nav_manager.html#a4d824d59792b47ac116cab7e9b81ec03',1,'TNKBaseNavManager']]],
  ['setprivacyagreement_3a_13',['setPrivacyAgreement:',['../interface_t_n_k_nav_services.html#a723cdaa25da84a86cbf2cd7c69faff35',1,'TNKNavServices']]],
  ['settotaldistancelabelcolor_3a_14',['setTotalDistanceLabelColor:',['../interface_t_n_k_navi_traffic_bar_widget.html#acda9947bb23739191d7c6e9f168ca443',1,'TNKNaviTrafficBarWidget']]],
  ['setuicomponentconfig_3a_15',['setUIComponentConfig:',['../interface_t_n_k_drive_nav_view.html#a1802aaec41ca3554ec32688c105b60bb',1,'TNKDriveNavView::setUIComponentConfig:()'],['../interface_t_n_k_ride_nav_view.html#adb3945a7a378a8fb0c5a905127587ecc',1,'TNKRideNavView::setUIComponentConfig:()'],['../interface_t_n_k_travel_nav_view.html#a8c075278825158b52561ab4fb275a795',1,'TNKTravelNavView::setUIComponentConfig:()']]],
  ['sharedinstance_16',['sharedInstance',['../interface_t_n_k_drive_nav_manager.html#a6804aa40a415c0f23ece04ff7ee7db33',1,'TNKDriveNavManager::sharedInstance()'],['../interface_t_n_k_drive_route_plan_service.html#a1c0aae54cf1fba332430c3ddd85b4bcf',1,'TNKDriveRoutePlanService::sharedInstance()'],['../interface_t_n_k_location_adapter.html#ae4b36c7e10e86f8f19811005b5db2237',1,'TNKLocationAdapter::sharedInstance()'],['../interface_t_n_k_logger.html#aa4f08077e665ec6488a9ef3de0e32e47',1,'TNKLogger::sharedInstance()'],['../interface_t_n_k_ride_nav_manager.html#a77a9e574c58ebb7eeb5beeb29321b9a7',1,'TNKRideNavManager::sharedInstance()'],['../interface_t_n_k_walk_nav_manager.html#aad687576020815b5c4d749ae0efb93ca',1,'TNKWalkNavManager::sharedInstance()']]],
  ['sharedservices_17',['sharedServices',['../interface_t_n_k_nav_services.html#af841d801f6321ccce40bdbed48fb4146',1,'TNKNavServices']]],
  ['startnavwithindex_3a_18',['startNavWithIndex:',['../interface_t_n_k_base_nav_manager.html#ada269e2e3f5e9b33d8c3474714a047ad',1,'TNKBaseNavManager']]],
  ['startnavwithrouteid_3a_19',['startNavWithRouteID:',['../interface_t_n_k_base_nav_manager.html#a4843f20d0f6676ad2e846baebfd85735',1,'TNKBaseNavManager']]],
  ['stateinterruption_20',['stateInterruption',['../protocol_t_n_k_audio_player_protocol-p.html#aa0091830480919d96d5130063eaa4f0e',1,'TNKAudioPlayerProtocol-p']]],
  ['stop_21',['stop',['../protocol_t_n_k_audio_player_protocol-p.html#acf3812e741d4e8a61277da8d7313a4a7',1,'TNKAudioPlayerProtocol-p']]],
  ['stopnav_22',['stopNav',['../interface_t_n_k_base_nav_manager.html#a112704dae565809b6a36cd91f41e9225',1,'TNKBaseNavManager']]]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/search/functions_a.js <==
var searchData=
[
  ['sdkversion_0',['sdkVersion',['../interface_t_n_k_nav_services.html#abdc1dd2cd0aa9bf243a908a8ad0c5341',1,'TNKNavServices']]],
  ['searchrouteswithrequest_3acompletion_3a_1',['searchRoutesWithRequest:completion:',['../interface_t_n_k_drive_nav_manager.html#ae012ed762cb37f3a8cd31f415dfb2916',1,'TNKDriveNavManager::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_drive_route_plan_service.html#a9406cba0843b5d35c4d6da759116bbcb',1,'TNKDriveRoutePlanService::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_ride_nav_manager.html#a1230430432ef55cfde29b4e65362ac67',1,'TNKRideNavManager::searchRoutesWithRequest:completion:()'],['../interface_t_n_k_walk_nav_manager.html#ab870679b698cf1b30fd1f38859d6941e',1,'TNKWalkNavManager::searchRoutesWithRequest:completion:()']]],
  ['setallcomponentvisibility_3a_2',['setAllComponentVisibility:',['../interface_t_n_k_drive_nav_view.html#a2d3478fcc22632d07261dfb881abf587',1,'TNKDriveNavView::setAllComponentVisibility:()'],['../interface_t_n_k_travel_nav_view.html#a3901489c5d84b7f90c364e889fce0ed9',1,'TNKTravelNavView::setAllComponentVisibility:()']]],
  ['setavoidareas_3a_3',['setAvoidAreas:',['../interface_t_n_k_drive_route_request.html#a1cc109bb2ec38709fdbc6c3dc4b0324e',1,'TNKDriveRouteRequest']]],
  ['setbackuprouteshidden_3abackuprouteids_3a_4',['setBackupRoutesHidden:backupRouteIDs:',['../interface_t_n_k_drive_nav_view.html#aef36f84cd4d60e072880e0c12d9d0479',1,'TNKDriveNavView::setBackupRoutesHidden:backupRouteIDs:()'],['../interface_t_n_k_travel_nav_view.html#afd822589919f5b5a65931299ea7dfad4',1,'TNKTravelNavView::setBackupRoutesHidden:backupRouteIDs:()']]],
  ['setcaricon_3asize_3a_5',['setCarIcon:size:',['../interface_t_n_k_navi_traffic_bar_widget.html#a6ae261ec2f5531a02dc130aa3b25f994',1,'TNKNaviTrafficBarWidget']]],
  ['setcustomareaheight_3a_6',['setCustomAreaHeight:',['../interface_t_n_k_travel_nav_view.html#acaa724d91ba411e2cb8e7a1f728624c5',1,'TNKTravelNavView']]],
  ['setdebuglog_3a_7',['setDebugLog:',['../interface_t_n_k_location_adapter.html#a69704e3eb0ece8a84744b979358e4bcb',1,'TNKLocationAdapter']]],
  ['setdestarriveoffrouteradius_3adestoffrouteradius_3a_8',['setDestArriveOffRouteRadius:destOffRouteRadius:',['../interface_t_n_k_drive_nav_manager.html#a8d49bbc52f699449b7ee78263dabb8ad',1,'TNKDriveNavManager']]],
  ['setheight_3a_9',['setHeight:',['../interface_t_n_k_custom_area_view.html#a4b368007cb0cd16648a7856cee7a8331',1,'TNKCustomAreaView']]],
  ['setlogon_3a_10',['setLogOn:',['../interface_t_n_k_logger.html#a5e167f9ee4688db33861bc2d1e07650d',1,'TNKLogger']]],
  ['setmapstyle_3a_11',['setMapStyle:',['../category_t_n_k_base_nav_view_07_q_map_view_08.html#a1dd5c15f6cf02b8da4a9aee650eb867c',1,'TNKBaseNavView(QMapView)::setMapStyle:()'],['../interface_t_n_k_base_nav_view.html#a1dd5c15f6cf02b8da4a9aee650eb867c',1,'TNKBaseNavView::setMapStyle:()']]],
  ['setnaverouteplancachesize_3a_12',['setNaveRoutePlanCacheSize:',['../interface_t_n_k_base_nav_manager.html#a4d824d59792b47ac116cab7e9b81ec03',1,'TNKBaseNavManager']]],
  ['setprivacyagreement_3a_13',['setPrivacyAgreement:',['../interface_t_n_k_nav_services.html#a723cdaa25da84a86cbf2cd7c69faff35',1,'TNKNavServices']]],
  ['settotaldistancelabelcolor_3a_14',['setTotalDistanceLabelColor:',['../interface_t_n_k_navi_traffic_bar_widget.html#acda9947bb23739191d7c6e9f168ca443',1,'TNKNaviTrafficBarWidget']]],
  ['setuicomponentconfig_3a_15',['setUIComponentConfig:',['../interface_t_n_k_drive_nav_view.html#a1802aaec41ca3554ec32688c105b60bb',1,'TNKDriveNavView::setUIComponentConfig:()'],['../interface_t_n_k_ride_nav_view.html#adb3945a7a378a8fb0c5a905127587ecc',1,'TNKRideNavView::setUIComponentConfig:()'],['../interface_t_n_k_travel_nav_view.html#a8c075278825158b52561ab4fb275a795',1,'TNKTravelNavView::setUIComponentConfig:()']]],
  ['sharedinstance_16',['sharedInstance',['../interface_t_n_k_drive_nav_manager.html#a6804aa40a415c0f23ece04ff7ee7db33',1,'TNKDriveNavManager::sharedInstance()'],['../interface_t_n_k_drive_route_plan_service.html#a1c0aae54cf1fba332430c3ddd85b4bcf',1,'TNKDriveRoutePlanService::sharedInstance()'],['../interface_t_n_k_location_adapter.html#ae4b36c7e10e86f8f19811005b5db2237',1,'TNKLocationAdapter::sharedInstance()'],['../interface_t_n_k_logger.html#aa4f08077e665ec6488a9ef3de0e32e47',1,'TNKLogger::sharedInstance()'],['../interface_t_n_k_ride_nav_manager.html#a77a9e574c58ebb7eeb5beeb29321b9a7',1,'TNKRideNavManager::sharedInstance()'],['../interface_t_n_k_walk_nav_manager.html#aad687576020815b5c4d749ae0efb93ca',1,'TNKWalkNavManager::sharedInstance()']]],
  ['sharedservices_17',['sharedServices',['../interface_t_n_k_nav_services.html#af841d801f6321ccce40bdbed48fb4146',1,'TNKNavServices']]],
  ['snapshotwithconfig_3acompletion_3a_18',['snapShotWithConfig:completion:',['../interface_t_n_k_ride_nav_view.html#a3bb3e97b7de53034bb81b335f123f49b',1,'TNKRideNavView']]],
  ['startnavwithindex_3a_19',['startNavWithIndex:',['../interface_t_n_k_base_nav_manager.html#ada269e2e3f5e9b33d8c3474714a047ad',1,'TNKBaseNavManager']]],
  ['startnavwithrouteid_3a_20',['startNavWithRouteID:',['../interface_t_n_k_base_nav_manager.html#a4843f20d0f6676ad2e846baebfd85735',1,'TNKBaseNavManager']]],
  ['stateinterruption_21',['stateInterruption',['../protocol_t_n_k_audio_player_protocol-p.html#aa0091830480919d96d5130063eaa4f0e',1,'TNKAudioPlayerProtocol-p']]],
  ['stop_22',['stop',['../protocol_t_n_k_audio_player_protocol-p.html#acf3812e741d4e8a61277da8d7313a4a7',1,'TNKAudioPlayerProtocol-p']]],
  ['stopnav_23',['stopNav',['../interface_t_n_k_base_nav_manager.html#a112704dae565809b6a36cd91f41e9225',1,'TNKBaseNavManager']]],
  ['stopsnapshot_24',['stopSnapShot',['../interface_t_n_k_ride_nav_view.html#ae9919b32f9f37e88c00361ee827712b4',1,'TNKRideNavView']]]
];
